==> metawiki-0.0.6.tar.gz: metawiki-0.0.6/metawiki/map.py <==
# Infinity namespace, to be defined on
# https://github.com/infamily/ooio/wiki
# and refered by keys starting with '_:'
INFINITY = {
    '_:{concept}': [
        'https://github.com/infamily/indb/wiki/{concept}',
        'https://raw.githubusercontent.com/wiki/infamily/indb/{concept}.md'
    ],
    '_:{concept}#{format}': [
        'https://github.com/infamily/indb/wiki/{concept}#{format}',
        'https://raw.githubusercontent.com/wiki/infamily/indb/{concept}.md#{format}'
    ]
}

# Wikidata namespace, to be defined on
# https://www.wikidata.org
# and refered by keys starting with 'WD:'
WIKIDATA = lambda N: {
    '%s:Q/{integer}' % (N,): [
        'https://www.wikidata.org/wiki/Q{integer}'
    ],
    '%s:P/{integer}' % (N,): [
        'https://www.wikidata.org/wiki/Property:P{integer}'
    ]
}

# Github ooio wiki namespace, to be defined on M repo wikis
# https://github.com/{user}/M/wiki/{concept}
# and refered by keys starting with 'N:{user}/{concept}'
GITHUB_WIKI = lambda N, M: {
    '%s:{user}/{concept}' % (N,): [
        'https://github.com/{user}/%s/wiki/{concept}' % (M,),
        'https://raw.githubusercontent.com/wiki/{user}/%s/{concept}.md' % (M,),
    ],
    '%s:{user}/{concept}#{format}' % (N,): [
        'https://github.com/{user}/%s/wiki/{concept}#{format}' % (M,),
        'https://raw.githubusercontent.com/wiki/{user}/%s/{concept}.md#{format}' % (M,),
    ]
}

# Files of ooio repos namespaces, to be defined on M repo files
# https://github.com/{user}/M/wiki/{concept}
# and refered by keys starting with 'N:{user}/{filename}'
GITHUB_FILE = lambda N, M: {
    '%s:{user}/{concept}' % (N,): [
        'https://github.com/{user}/%s/blob/master/{concept}' % (M,),
        'https://raw.githubusercontent.com/{user}/%s/{concept}' % (M,),
    ],
    '%s:{user}/{concept}#{format}' % (N,): [
        'https://github.com/{user}/%s/blob/master/{concept}#{format}' % (M,),
        'https://raw.githubusercontent.com/{user}/%s/{concept}#{format}' % (M,),
    ]
}


N = {}
N.update(INFINITY)
N.update(WIKIDATA('WD'))
N.update(GITHUB_WIKI('IN', 'ooio')) # WIKIs of ooio repos
N.update(GITHUB_FILE('FN', 'ooio')) # FILEs of ooio repos
MAP = N

==> metawiki-0.0.7.tar.gz: metawiki-0.0.7/metawiki/map.py <==
NAMESPACES = {}


# Infinity namespace, to be defined on
# https://github.com/infamily/ooio/wiki
# and refered by keys starting with '_:'
INFINITY = {
    '_:{concept}': [
        'https://github.com/infamily/indb/wiki/{concept}',
        'https://raw.githubusercontent.com/wiki/infamily/indb/{concept}.md'
    ],
    '_:{concept}#{format}': [
        'https://github.com/infamily/indb/wiki/{concept}#{format}',
        'https://raw.githubusercontent.com/wiki/infamily/indb/{concept}.md#{format}'
    ]
}
NAMESPACES['_:'] = INFINITY


# Wikidata namespace, to be defined on
# https://www.wikidata.org
# and refered by keys starting with 'WD:'
WIKIDATA = lambda N: {
    '%s:Q/{integer}' % (N,): [
        'https://www.wikidata.org/wiki/Q{integer}'
    ],
    '%s:P/{integer}' % (N,): [
        'https://www.wikidata.org/wiki/Property:P{integer}'
    ]
}
NAMESPACES['WD:'] = WIKIDATA('WD')


# Github ooio wiki namespace, to be defined on M repo wikis
# https://github.com/{user}/M/wiki/{concept}
# and refered by keys starting with 'N:{user}/{concept}'
GITHUB_WIKI = lambda N, M: {
    '%s:{user}/{concept}' % (N,): [
        'https://github.com/{user}/%s/wiki/{concept}' % (M,),
        'https://raw.githubusercontent.com/wiki/{user}/%s/{concept}.md' % (M,),
    ],
    '%s:{user}/{concept}#{format}' % (N,): [
        'https://github.com/{user}/%s/wiki/{concept}#{format}' % (M,),
        'https://raw.githubusercontent.com/wiki/{user}/%s/{concept}.md#{format}' % (M,),
    ]
}
NAMESPACES['IN:'] = GITHUB_WIKI('IN', 'ooio') # WIKIs of ooio repos

# Files of ooio repos namespaces, to be defined on M repo files
# https://github.com/{user}/M/wiki/{concept}
# and refered by keys starting with 'N:{user}/{filename}'
GITHUB_FILE = lambda N, M: {
    '%s:{user}/{concept}' % (N,): [
        'https://github.com/{user}/%s/blob/master/{concept}' % (M,),
        'https://raw.githubusercontent.com/{user}/%s/{concept}' % (M,),
    ],
    '%s:{user}/{concept}#{format}' % (N,): [
        'https://github.com/{user}/%s/blob/master/{concept}#{format}' % (M,),
        'https://raw.githubusercontent.com/{user}/%s/{concept}#{format}' % (M,),
    ]
}
NAMESPACES['FN:'] = GITHUB_FILE('FN', 'ooio') # FILEs of ooio repos


MAP = {}

for key, value in NAMESPACES.items():
    MAP = dict(MAP, **value)
